# Linum

<p align="center">
    <img src="https://i.postimg.cc/rFWHwqwq/Artboard-1-0-5x.png" alt="Linum logo">
</p>

[![Documentation Status](https://readthedocs.org/projects/linum/badge/?version=latest)](https://linum.readthedocs.io/en/latest/?badge=latest)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Build Status](https://travis-ci.com/chabErch/Linum.svg?branch=master)](https://travis-ci.com/chabErch/Linum)

The tool for tasks visualization - like Gantt chart, but more compact.

Full documentation are [available here](https://linum.readthedocs.io/). Also there is the [GitHub project page](https://github.com/chabErch/Linum).

## Description

If you need to visualize your schedule or working plan you are welcome to use Linum. Actually, you are able to use Gantt charts, but they are overloaded with extra information if you have many simple tasks. Gantt charts are better when tasks are sequential and connected between themselves. 

Linum allows you to visualize your information on chosen time interval
(week, month, year) like a timetable briefly and convenient.

### Supported output formats

- Console
- Text (.txt)
- Excel (.xlsx)
- SVG (.svg)

### Coming soon output formats

- HTML (.html)
- InDesign (.idml)

## Render examples

### TXT renderer

[![image-2021-05-10-00-29-15.png](https://i.postimg.cc/zB3QnTbL/image-2021-05-10-00-29-15.png)](https://postimg.cc/ZBtjmBLZ)

### XLSX renderer

[![image-2021-05-10-00-15-25.png](https://i.postimg.cc/NM7SbdJ0/image-2021-05-10-00-15-25.png)](https://postimg.cc/hzv2t1qF)

### SVG renderer

[![svg-renderer.png](https://i.postimg.cc/6psCNTzn/svg-renderer.png)](https://postimg.cc/qzLNsJPv)

## Contributing

For now Linum is ready to go for rendering your tasks in several formats on a chosen time interval.
Feel free to improve the project and develop any new output formats.

## Author

- [Chaberch](https://github.com/chabErch)
